@@ -100,6 +100,14 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     super();
   }
 
+  /**
+   * Returns true if the current value of the reader is not null
+   * @return
+   */
+  public boolean isSet() {
+    return true;
+  }
+
   
   public Object readObject(int arrayIndex){
     fail("readObject(int arrayIndex)");
@@ -272,14 +280,16 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
   public void copyAsField(String name, MapWriter writer){
     fail("CopyAsField MapWriter");
   }
-  public void copyAsValue(ListWriter writer){
-    fail("CopyAsValueList");
-  }
+
   public void copyAsField(String name, ListWriter writer){
     fail("CopyAsFieldList");
   }
   
 
+  public void read(TinyIntHolder holder){
+    fail("TinyInt");
+  }
+
   public void read(NullableTinyIntHolder holder){
     fail("TinyInt");
   }
@@ -299,6 +309,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldTinyInt");
   }
 
+  public void read(UInt1Holder holder){
+    fail("UInt1");
+  }
+
   public void read(NullableUInt1Holder holder){
     fail("UInt1");
   }
@@ -318,6 +332,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldUInt1");
   }
 
+  public void read(UInt2Holder holder){
+    fail("UInt2");
+  }
+
   public void read(NullableUInt2Holder holder){
     fail("UInt2");
   }
@@ -337,6 +355,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldUInt2");
   }
 
+  public void read(SmallIntHolder holder){
+    fail("SmallInt");
+  }
+
   public void read(NullableSmallIntHolder holder){
     fail("SmallInt");
   }
@@ -356,6 +378,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldSmallInt");
   }
 
+  public void read(IntHolder holder){
+    fail("Int");
+  }
+
   public void read(NullableIntHolder holder){
     fail("Int");
   }
@@ -375,6 +401,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldInt");
   }
 
+  public void read(UInt4Holder holder){
+    fail("UInt4");
+  }
+
   public void read(NullableUInt4Holder holder){
     fail("UInt4");
   }
@@ -394,6 +424,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldUInt4");
   }
 
+  public void read(Float4Holder holder){
+    fail("Float4");
+  }
+
   public void read(NullableFloat4Holder holder){
     fail("Float4");
   }
@@ -413,6 +447,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldFloat4");
   }
 
+  public void read(TimeHolder holder){
+    fail("Time");
+  }
+
   public void read(NullableTimeHolder holder){
     fail("Time");
   }
@@ -432,6 +470,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldTime");
   }
 
+  public void read(IntervalYearHolder holder){
+    fail("IntervalYear");
+  }
+
   public void read(NullableIntervalYearHolder holder){
     fail("IntervalYear");
   }
@@ -451,6 +493,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldIntervalYear");
   }
 
+  public void read(Decimal9Holder holder){
+    fail("Decimal9");
+  }
+
   public void read(NullableDecimal9Holder holder){
     fail("Decimal9");
   }
@@ -470,6 +516,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldDecimal9");
   }
 
+  public void read(BigIntHolder holder){
+    fail("BigInt");
+  }
+
   public void read(NullableBigIntHolder holder){
     fail("BigInt");
   }
@@ -489,6 +539,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldBigInt");
   }
 
+  public void read(UInt8Holder holder){
+    fail("UInt8");
+  }
+
   public void read(NullableUInt8Holder holder){
     fail("UInt8");
   }
@@ -508,6 +562,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldUInt8");
   }
 
+  public void read(Float8Holder holder){
+    fail("Float8");
+  }
+
   public void read(NullableFloat8Holder holder){
     fail("Float8");
   }
@@ -527,6 +585,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldFloat8");
   }
 
+  public void read(DateHolder holder){
+    fail("Date");
+  }
+
   public void read(NullableDateHolder holder){
     fail("Date");
   }
@@ -546,6 +608,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldDate");
   }
 
+  public void read(TimeStampHolder holder){
+    fail("TimeStamp");
+  }
+
   public void read(NullableTimeStampHolder holder){
     fail("TimeStamp");
   }
@@ -565,6 +631,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldTimeStamp");
   }
 
+  public void read(Decimal18Holder holder){
+    fail("Decimal18");
+  }
+
   public void read(NullableDecimal18Holder holder){
     fail("Decimal18");
   }
@@ -584,6 +654,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldDecimal18");
   }
 
+  public void read(IntervalDayHolder holder){
+    fail("IntervalDay");
+  }
+
   public void read(NullableIntervalDayHolder holder){
     fail("IntervalDay");
   }
@@ -603,6 +677,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldIntervalDay");
   }
 
+  public void read(IntervalHolder holder){
+    fail("Interval");
+  }
+
   public void read(NullableIntervalHolder holder){
     fail("Interval");
   }
@@ -622,6 +700,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldInterval");
   }
 
+  public void read(Decimal28DenseHolder holder){
+    fail("Decimal28Dense");
+  }
+
   public void read(NullableDecimal28DenseHolder holder){
     fail("Decimal28Dense");
   }
@@ -641,6 +723,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldDecimal28Dense");
   }
 
+  public void read(Decimal38DenseHolder holder){
+    fail("Decimal38Dense");
+  }
+
   public void read(NullableDecimal38DenseHolder holder){
     fail("Decimal38Dense");
   }
@@ -660,6 +746,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldDecimal38Dense");
   }
 
+  public void read(Decimal38SparseHolder holder){
+    fail("Decimal38Sparse");
+  }
+
   public void read(NullableDecimal38SparseHolder holder){
     fail("Decimal38Sparse");
   }
@@ -679,6 +769,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldDecimal38Sparse");
   }
 
+  public void read(Decimal28SparseHolder holder){
+    fail("Decimal28Sparse");
+  }
+
   public void read(NullableDecimal28SparseHolder holder){
     fail("Decimal28Sparse");
   }
@@ -698,6 +792,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldDecimal28Sparse");
   }
 
+  public void read(VarBinaryHolder holder){
+    fail("VarBinary");
+  }
+
   public void read(NullableVarBinaryHolder holder){
     fail("VarBinary");
   }
@@ -717,6 +815,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldVarBinary");
   }
 
+  public void read(VarCharHolder holder){
+    fail("VarChar");
+  }
+
   public void read(NullableVarCharHolder holder){
     fail("VarChar");
   }
@@ -736,6 +838,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldVarChar");
   }
 
+  public void read(Var16CharHolder holder){
+    fail("Var16Char");
+  }
+
   public void read(NullableVar16CharHolder holder){
     fail("Var16Char");
   }
@@ -755,6 +861,10 @@ abstract class AbstractFieldReader extends AbstractBaseReader implements FieldRe
     fail("CopyAsFieldVar16Char");
   }
 
+  public void read(BitHolder holder){
+    fail("Bit");
+  }
+
   public void read(NullableBitHolder holder){
     fail("Bit");
   }
