@@ -123,10 +123,16 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
 
   public void copyAsValue(ListWriter writer) {}
 
+  public void copyAsValue(UnionWriter writer) {}
+
+  public void read(TinyIntHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableTinyIntHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, TinyIntHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -137,10 +143,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableTinyIntHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(UInt1Holder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableUInt1Holder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, UInt1Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -151,10 +161,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableUInt1Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(UInt2Holder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableUInt2Holder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, UInt2Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -165,10 +179,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableUInt2Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(SmallIntHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableSmallIntHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, SmallIntHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -179,10 +197,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableSmallIntHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(IntHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableIntHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, IntHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -193,10 +215,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableIntHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(UInt4Holder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableUInt4Holder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, UInt4Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -207,10 +233,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableUInt4Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(Float4Holder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableFloat4Holder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, Float4Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -221,10 +251,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableFloat4Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(TimeHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableTimeHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, TimeHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -235,10 +269,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableTimeHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(IntervalYearHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableIntervalYearHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, IntervalYearHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -249,10 +287,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableIntervalYearHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(Decimal9Holder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableDecimal9Holder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, Decimal9Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -263,10 +305,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableDecimal9Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(BigIntHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableBigIntHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, BigIntHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -277,10 +323,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableBigIntHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(UInt8Holder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableUInt8Holder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, UInt8Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -291,10 +341,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableUInt8Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(Float8Holder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableFloat8Holder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, Float8Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -305,10 +359,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableFloat8Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(DateHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableDateHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, DateHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -319,10 +377,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableDateHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(TimeStampHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableTimeStampHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, TimeStampHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -333,10 +395,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableTimeStampHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(Decimal18Holder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableDecimal18Holder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, Decimal18Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -347,10 +413,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableDecimal18Holder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(IntervalDayHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableIntervalDayHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, IntervalDayHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -361,10 +431,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableIntervalDayHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(IntervalHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableIntervalHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, IntervalHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -375,10 +449,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableIntervalHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(Decimal28DenseHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableDecimal28DenseHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, Decimal28DenseHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -389,10 +467,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableDecimal28DenseHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(Decimal38DenseHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableDecimal38DenseHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, Decimal38DenseHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -403,10 +485,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableDecimal38DenseHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(Decimal38SparseHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableDecimal38SparseHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, Decimal38SparseHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -417,10 +503,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableDecimal38SparseHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(Decimal28SparseHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableDecimal28SparseHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, Decimal28SparseHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -431,10 +521,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableDecimal28SparseHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(VarBinaryHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableVarBinaryHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, VarBinaryHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -445,10 +539,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableVarBinaryHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(VarCharHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableVarCharHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, VarCharHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -459,10 +557,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableVarCharHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(Var16CharHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableVar16CharHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, Var16CharHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
@@ -473,10 +575,14 @@ public class NullReader extends AbstractBaseReader implements FieldReader{
   public void read(int arrayIndex, NullableVar16CharHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
+  public void read(BitHolder holder){
+    throw new UnsupportedOperationException("NullReader cannot write into non-nullable holder");
+  }
+
   public void read(NullableBitHolder holder){
     holder.isSet = 0;
   }
-  
+
   public void read(int arrayIndex, BitHolder holder){
     throw new ArrayIndexOutOfBoundsException();
   }
